pub struct InputMessage {
pub occurred_at: Option<Timestamp>,
pub mime: String,
pub data: Vec<u8>,
}Expand description
InputMessage describes a message that can be sent to an input
Fields
occurred_at: Option<Timestamp>OccurredAt is the UTC timestamp of the message. Typically this is either the time at which an application sent this message or the time applicable to the message itself. (Optional: set to host time if not provided)
mime: StringMime is the mime type of the encoded data.
data: Vec<u8>Data is the actual message, encoded according the the mime type. The data should follow the Input’s value definitions but that is not enforced. (See also Value)